=======
Credits
=======

Development Leads
-----------------

- `Xiaokui Shu`_
- `Paul Coccoli`_

Contributors
------------

- `Charlie Wu`_
- `Jill Casavant`_

.. _Xiaokui Shu: https://github.com/subbyte
.. _Paul Coccoli: https://github.com/pcoccoli
.. _Charlie Wu: https://github.com/charliewutw
.. _Jill Casavant: https://github.com/jmcasava
